pub enum FinalityProof {
Assumption,
HotStuff2 {
committing_qc: Arc<Certificate>,
deciding_qc: Arc<Certificate>,
},
HotStuff {
precommit_qc: Arc<Certificate>,
committing_qc: Arc<Certificate>,
deciding_qc: Arc<Certificate>,
},
}Expand description
Data sufficient to convince a client that a certain leaf is finalized.
There are different types of proofs for different scenarios and protocol versions. New proof types can be added while remaining compatible with old serialized proofs.
Variants
Assumption
The client has stated that they already trust the finality of this particular leaf.
HotStuff2
The finality follows from a 2-chain of QCs using the HotStuff2 commit rule.
The requirements for checking finality of a leaf given a 2-chain of QCs are:
- The leaf has a protocol version indicating it was created via HotStuff2
committing_qc.leaf_commit() == leaf.commit()committing_qc.view_number() == leaf.view_number()deciding_qc.view_number() == committing_qc.view_number() + 1- Both QCs have a valid threshold signature given a stake table
HotStuff
The finality follows from a 3-chain of QCs using the original HotStuff commit rule.
The requirements for checking finality of a leaf via the 3-chain rule are similar to the
HotStuff2 finality rule, but an extra QC is required with a consecutive view number.
Implementations
Sourceimpl FinalityProof
impl FinalityProof
Sourcepub fn epoch(&self) -> Option<EpochNumber>
pub fn epoch(&self) -> Option<EpochNumber>
The epoch number whose quorum is needed to verify this proof.
This determines the kind of LeafProofHint needed to verify the proof. If Some, then
a LeafProofHint::Quorum is needed with a quorum from this epoch. If None, then a
LeafProofHint::Assumption is needed.